@@ -71,3 +71,15 @@ test_that("cXbar15", {
 test_that("cXbar16", {
     check_ui_test(cXbar16())
 })
+
+test_that("cXbar17", {
+    check_ui_test(cXbar17())
+})
+
+test_that("cXbar18", {
+    check_ui_test(cXbar18())
+})
+
+test_that("cXbar19", {
+    check_ui_test(cXbar19())
+})
