@@ -69,3 +69,11 @@ test_that("cXheatmap14", {
 test_that("cXheatmap15", {
     check_ui_test(cXheatmap15())
 })
+
+test_that("cXheatmap16", {
+    check_ui_test(cXheatmap16())
+})
+
+test_that("cXheatmap17", {
+    check_ui_test(cXheatmap17())
+})
