@@ -20,3 +20,7 @@ test_that("cXtree4", {
 test_that("cXtree5", {
     check_ui_test(cXtree5())
 })
+
+test_that("cXtree6", {
+    check_ui_test(cXtree6())
+})
